@@ -29,8 +29,8 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.69";
-static const char man_date[] = "October 2021";
+static const char man_version[] = "11.70";
+static const char man_date[] = "November 2021";
 
 /* ----------------------------------
  * definitions
